summaryrefslogtreecommitdiff
path: root/include/vcl/bitmap.hxx
diff options
context:
space:
mode:
authorNoel Grandin <noel.grandin@collabora.co.uk>2018-04-16 11:27:31 +0200
committerNoel Grandin <noel.grandin@collabora.co.uk>2018-04-17 15:07:13 +0200
commitf462a76f2bbaaaaaa79bf935a51bdf8cead25dbb (patch)
tree745b09434515a712d8af42626e0f7ef1dd6871db /include/vcl/bitmap.hxx
parent432c7dd62b3ea7634a43850ea937c6bc681884d8 (diff)
remove ImpBitmap
it's not adding anything useful, just hold the underlying SalBitmap instead Change-Id: I54852707b2f8af99283b9c882a428a8a7a11c4cf Reviewed-on: https://gerrit.libreoffice.org/52955 Tested-by: Jenkins <ci@libreoffice.org> Reviewed-by: Noel Grandin <noel.grandin@collabora.co.uk>
Diffstat (limited to 'include/vcl/bitmap.hxx')
-rw-r--r--include/vcl/bitmap.hxx15
1 files changed, 7 insertions, 8 deletions
diff --git a/include/vcl/bitmap.hxx b/include/vcl/bitmap.hxx
index 5740fc38eb63..cc50a6dc9bcc 100644
--- a/include/vcl/bitmap.hxx
+++ b/include/vcl/bitmap.hxx
@@ -187,7 +187,6 @@ class BitmapInfoAccess;
class BitmapReadAccess;
class BitmapWriteAccess;
class BitmapPalette;
-class ImpBitmap;
class Color;
class GDIMetaFile;
class AlphaMask;
@@ -227,8 +226,8 @@ public:
inline bool operator!() const;
bool operator==( const Bitmap& rBitmap ) const;
bool operator!=( const Bitmap& rBitmap ) const { return !operator==(rBitmap); }
- // only compares if we are using the same internal copy-on-write Impl class
- bool ShallowEquals( const Bitmap& rBitmap ) const { return mxImpBmp == rBitmap.mxImpBmp; }
+ // only compares if we are using the same internal copy-on-write SalBitmap class
+ bool ShallowEquals( const Bitmap& rBitmap ) const { return mxSalBmp == rBitmap.mxSalBmp; }
inline bool IsEmpty() const;
void SetEmpty();
@@ -671,8 +670,8 @@ public:
SAL_DLLPRIVATE void ReassignWithSize(const Bitmap& rBitmap);
SAL_DLLPRIVATE void ImplMakeUnique();
- const std::shared_ptr<ImpBitmap>& ImplGetImpBitmap() const { return mxImpBmp; }
- SAL_DLLPRIVATE void ImplSetImpBitmap( const std::shared_ptr<ImpBitmap>& xImpBmp );
+ const std::shared_ptr<SalBitmap>& ImplGetSalBitmap() const { return mxSalBmp; }
+ SAL_DLLPRIVATE void ImplSetSalBitmap( const std::shared_ptr<SalBitmap>& xImpBmp );
SAL_DLLPRIVATE bool ImplScaleFast( const double& rScaleX, const double& rScaleY );
SAL_DLLPRIVATE bool ImplScaleInterpolate( const double& rScaleX, const double& rScaleY );
@@ -736,7 +735,7 @@ private:
SAL_DLLPRIVATE bool ImplConvertGhosted();
private:
- std::shared_ptr<ImpBitmap> mxImpBmp;
+ std::shared_ptr<SalBitmap> mxSalBmp;
MapMode maPrefMapMode;
Size maPrefSize;
@@ -744,12 +743,12 @@ private:
inline bool Bitmap::operator!() const
{
- return( mxImpBmp == nullptr );
+ return( mxSalBmp == nullptr );
}
inline bool Bitmap::IsEmpty() const
{
- return( mxImpBmp == nullptr );
+ return( mxSalBmp == nullptr );
}
inline const MapMode& Bitmap::GetPrefMapMode() const